XHYDEX Users Manual




A.G. Orpen

School of Chemistry
University of Bristol
Bristol, BS8 1TS, UK.



TABLE OF CONTENTS

1.	Introduction
2.	Program Specifications and Installation
3.	Using the program
4. 	Input to the program
4.1	Instructions
5.	Examples
6.	RULES 
7.	APPENDIX
7.1	Potential energy parameters
7.2	Metal-Hydride bond lengths
7.3	Some Neutron Determined Bond Lengths 

XHYDEX: A Program for Locating Hydrides in Metal Complexes

1.	Introduction
XHYDEX is a program written in a simple subset of Fortran (designed 
to be reasonably machine independent) which uses crystallographically 
determined molecular parameters to infer the positions of hydride 
ligands in metal cluster complexes.   The procedure is of special 
interest for cluster compounds of 2nd and 3rd row transition elements 
where direct X-ray location of hydrogen atoms is very difficult and 
qualitative indirect hydride location sometimes ambiguous.
The program finds optimised hydride positions, given X-ray structural 
parameters for non-hydrogen atoms, such that the hydride is bonded to 
1, 2 or 3 atoms (usually metals) at user specified bond lengths.   
The optimised positions are at suitable minima of a potential energy 
defined by intra- molecular non-bonded interactions between the 
postulated hydride position and other atoms subject to the 
appropriate bond length constraints.   The optimised sites thus 
located agree well with those found by neutron diffraction methods 
for almost all cases in the literature (r.m.s. error ca. 0.05  ).   
When more than one hydride is known to be present in the cluster the 
non-bonded interactions between hydride sites can be taken into 
account in order to ensure the compatibility of proposed sites.   A 
picture of the molecule projected onto a user specified plane through 
the unit cell, and a map of the appropriate potential energy function 
in this plane may be obtained.   This facility is especially useful 
in checking for multiple hydride sites on a cluster edge or around a 
metal centre.   The program thus provides an easily used semi-
quantitative procedure for inferring hydride positions inaccessible 
from single crystal X-ray data alone.

2.	Program Specifications and Installation
The program consists of about 1040 FORTRAN statements contained in a 
main program and subroutines.   It is supplied together with three 
test jobs checking features of the program and listings of the output 
produced by these jobs by electronic means.   Documentation is 
provided separately.
The program has been extensively tested on a variety of computers and 
should prove readily adaptable. The main aspect requiring attention 
when installing concerns contour map plotting. This is carried out 
using CALCOMP subroutines BRKPLT and PLOT at or near line 611 of the 
main program and in subroutine XPLOD respectively. These routines 
will need to be replaced with others should you wish to exploit this 
aspect of the program.   

The Fortran unit numbers used by READ and WRITE statements are 
specified as integers NIN and NOUT in the DATA statement of the main 
program.   The program assumes there to be at least 110 line printer 
characters available across the page, the number of characters per 
inch across and down the page may be specified as real variables HA 
and HD in the main program DATA statement.   The program requires at 
least 24 bit integer word length.   Default settings of NIN, NOUT, HD 
and HA are 5, 6, 8 and 10 respectively.

Three test jobs are supplied with the program.   The output from 
these jobs should be as in the output listings provided, and is 
discussed in the Examples section.   
Users of the program should refer to the literature description of 
the program and its use:  A.G. Orpen, J. Chem . Soc., Dalton Trans.,  
1980, 2509.

3.	Using the program
The examples in the test data provided show typical use of the 
program.   Given (X-ray) structural parameters for the non-hydrogen 
atoms in a cluster compound it is possible to conduct initial 
searches for hydride sites on edges and faces of the cluster as well 
as in terminal positions, using the TERM, EDGE AND FACB instructions 
as appropriate.   A conjugate-gradient technique is used (derived 
from that of Fletcher and Reeves, Computer J. (1964) 7, 149) which 
finds local minima of the potential energy function (including the 
bond length constraints) appropriate to the hydride specified.   In 
an initial search interactions are evaluated for all atoms within a 
restricted 'search radius' (see test output) of an initial estimate 
of the hydride position.   Twenty-six starting hydride positions 
around this estimate are refined and each optimised position checked 
for suitability.   Positions too close to a non-bonded atom are 
rejected, as are those where the M-H bond length is too far from that 
specified, when convergence of a particular optimisation is slow and 
therefore incomplete a message to that effect is output.   The unique 
'suitable' positions  are further refined and their coordinates and 
potential energies (excluding the bond length term) output.
This technique ensures location of separated multiple hydride sites 
in cases where more than one hydride is bound to a vertex, edge or 
face of a cluster.   The output table in inter-minima distances 
enables the user to check for short hydride-hydride contacts (inter-
hydride distances as short as 1.85  apart, are known).    The co-
refinement of hydride positions is possible using the HLOC command 
and is recommended in cases where the hydrides are sufficiently close 
to one another to have significant non-bonded interactions (less than 
3  apart, say).    Multiple hydride sites may well not be detected 
in an initial search and only be revealed by use of the PLOT command.   
They are typified by abnormally low potential energy minima and/or 
unusually diffuse or extended potential minimum shape (see examples).
Typical hydride site energies are in the range 0-3.5 units whereas 
false minima have higher energies greater than 10 units.   Energies 
are not on an absolute scale but show relatively little variation 
between different molecules and site types.   Thus typically terminal 
sites are of slightly higher energy than edge bridging or triply 
bridging sites.
The program has been widely used in the past fifteen years.   Initial 
testing was done against neutron diffraction data and showed r.m.s. 
disagreement with neutron determined hydride position of ca. 0.05 .  
(See A.G. Orpen, J. Chem. Soc., Dalton Trans., 1980, 2509).   
Difficulties are most likely to arise when the non-hydride ligand 
framework is sparse (i.e. polyhydrides) or the distribution of ligand 
atoms is far from spherical (e.g. in locally square planar 
environments).

4. 	Input to the program
All instructions are read as 80 character instructions and supply the 
program with information regarding unit cell dimensions, atomic 
positions and types, potential energy parameters and define which 
calculations are to be carried out.
The first four characters define the type of instruction.   A 
instruction is assumed to be an 'atom instruction' if not recognised 
by the program to be otherwise.   The remaining 76 characters are 
used to convey numerical information in machine-independent free 
format with blanks separating the numbers.   Faulty or illegal 
instructions are either ignored or cause the program to halt further 
execution of instructions and return an error message.
The first and second instructions of any job must be the TITL and 
CELL instructions respectively, the last must be the END instruction.    
Instructions with the first four characters blank are ignored and may 
be used to include comments, all input instructions are reflected in 
the lineprinter output before being obeyed.   Reading END or END+ 
causes the program to execute the preceding instructions.

4.1	Instructions
	TITL	followed by a title of up to 40 characters.
	CELL	a, b, c. alpha, beta,  gamma in ngstroms and degrees.
	PARM	n, a, b, c, d.
where n is the atom type number and a, b, c, d are potential energy 
parameters appropriate for to describe the non-bonded interaction of 
the hydride with atoms of type n. The potential energy function used 
in the program is:  V(r) = a(e-br)/rd - c/r6.
See the Appendix for suitable values for a,b,c and d. Default values 
for a, b, c and d are those given for carbon atoms in the Appendix, 
inter-hydride terms required when using the HLOC instruction are 
calculated using the parameters given for hydrogen atoms.

	TERM	n1, d, sd, ni
this initiates a search for terminal hydride sites at a bond length 
d from the n1th atom in the atom list input.   Sd is the permitted 
'uncertainty' in this bond length, a constraint is applied to the 
minimisation process by adding a term equal to mod(observed bond 
length - d)/(sd*sd) to the potential energy function to be minimised.   
This ensures that the minima found by the program are at suitable 
bond lengths.   The minimised potential energies output after the 
completion of the calculations exclude this term.   ni sets an upper 
limit on the number of potential energy function evaluations which 
may be made during the minimisation process.   Default values of d, 
sd and ni are 1.60, 0.05 and 250.

	EDGE	n1, n2, d1, d2, sd1, sd2, ni
as for the TERM instruction this causes a search for a hydride bonded 
to atoms n1th and n2th in the atom list at bond lengths d1, d2 
respectively.   Default settings of d, sd, and ni are 1.85, 0.05 and 
250.   If d2 is not given (i.e. sd, sd2 and ni are also omitted) then 
d2 is assumed equal to d1.

	FACB	n1, n2, n3, d1, d2, d3, sd1, sd2, sd3, ni
as for EDGE and TERM instructions this causes a search for a hydride 
bonded to the n1th, n2th and n3th atoms in the atom list at bond 
lengths d1, d2 and d3  respectively.   Default settings of d, sd and 
ni are 1.95, 0.05 and 250.   If d2, d3 etc. are omitted then d2 = d3 
= d1 is assumed.

	MATR	p11, p12, p13, p21, p22, p23, p31, p32, p33
defines an orientation matrix P, such that P gives plot coordinates 
from orthogonal coordinates XO, YO, ZO (where the XO axis is parallel 
to x*, YO parallel to zXx* and ZO to z).  X', Y', Z' are the 
coordinates for 'plots' requested by subsequent PLOT instructions 
(where X' = p11*XO + p12*YO + p13*ZO etc., see J.S. Rollett, 
Computing Methods in Crystallography, Pergamon (1965) p. 22.)   X' 
runs down the page, Y' across the page and Z' vertically out of the 
paper. This convention is used in the Siemens proprietary program XP 
and its forbears (such as XMOL).

	PLOT	x, y, z, h, n1 .... nh, s, d1, .... dh, sd, .... sdh
this causes a line-printer plot of the molecule, size 2*s*HA/HD along 
X1 by 2*s  along Y1 centered on x, y, z and projected onto a plane 
defined by x, y, z and the orientation matrix P, (set by a preceding 
MATR instruction) and an identically scaled plot of the potential 
energy function in this plane suitable for hand contouring.   This 
may be as for terminal, edge-bridging or face capping hydride (h = 1, 
2 or 3 respectively) bonded to atoms n1, ... nh in the atom list at 
bond length(s) d1, ... dh  uncertainty sd1, ... sdh (if only one of 
d1, d2 is given when h = 2 then d2  is assumed = d1, likewise if d2 
and d3 is not given when h = 3 then d3 = d2 = d1 is assumed for sd1, 
... sdh).

	CONT	n, co, c1, ... cn
This instruction specifies the contour levels to be used in the 
contouring g of the potential energy function in the specified plane.   
There will be n contours and those below co will be broken lines, and 
levels at which contours are to be drawn will be c1, c2, ...cn.   
Both the potential energy contours and a stick drawing of the 
molecule projected in to the  plane are drawn.

	HLOC		x, y, z, h, n1 ... nh, d1,  ... dh, sd, ... sdh
is used to refine a hydride position as determined by initial use of 
TERM, EDGE or FACB instructions.   Up to 10 HLOC instructions may be 
used in one job to co-refine hydride positions at x, y, z (as for the 
PLOT instruction), at bond lengths d1 ... dh from the n1th ... nhth 
atoms in the atom list (uncertainty sd1, ... sdh ).   Inter-hydride 
potential energy terms are evaluated using the parameters given in 
the Appendix for hydrogen atoms, the hydrides refined are included at 
the end of the atom list with atom names HLn (n = 1, ... 10)

	atom instructions		name (4 characters), type, x, y, z
these are recognised as atom instructions if the given name does not 
correspond to a permitted instruction, the atom type corresponds to 
the appropriate PARM instruction (where given).   Further numbers on 
this instruction e.g. Uij etc. are ignored.

	END+
indicates the end of a segment of a job and initiates execution of 
preceding instructions, and is followed by further instructions to be 
executed.

	END
is the obligatory final instruction of a job.

5.	Examples
Four test jobs illustrating the use of all the commands available in 
the program are included with the program provided. For discussion of 
the outcomes of these hydride location attempts see A.G. Orpen, J. 
Chem . Soc., Dalton Trans.,  1980, 2509.

JOB 1. 	This job is typical initial hydride search on a tetrahedral 
osmium cluster compound [H3Os4(CO)11C6H9].   All non-hydrogen atoms 
have been located from an X-ray study and are included in the input 
deck with the appropriate TITL and CELL instructions.   Suitable 
potential energy parameters are used for the various atom types 
present and four of the edges and two of the triangular faces of the 
cluster are searched for minima.
The output from this job reflects all the input instructions and 
gives details of the results of the various minima searches carried 
out.   Each search is preceded by a heading indicating the type of 
hydride being searched for, and the bond lengths (and uncertainties) 
to be used, in addition to the search radius within which non-bonded 
potential energies will be evaluated (usually 3.5-4.0 ).   26 
attempts are made to locate the minima and optimised positions are 
output after each attempt together with their potential energies and 
a comment on their suitability, the unique solutions are then further 
refined.   This process is repeated for all 6 requested searches and 
the summary of refined hydride sites at the end of the output shows 
all minimum energies and the inter-minima distances as well as bonded 
and non-bonded distances to other atoms.   In this case three edges 
of the cluster show how single low energy minima typical of hydrides 
bridging edges of a carbonyl cluster.   The remaining faces and edges 
tested clearly are not bridged as indicated by either no suitable 
sites being located or only high energy minima being found.

JOB 2.	This job illustrates use of the PLOT command to check for 
multiple minima undetected by an initial search.   After TITL, CELL, 
atom and PARM instructions the TERM instruction is read in causing a 
search for a terminal hydride in the mononuclear compound 
[H3Re(P(Ph)2CH2CH2P(Ph)2)2].   The MATR instruction causes the plots 
to be in the equatorial plane of the pentagonal bipyramidally 
coordinated rhenium, with the plots centered on that atom.   The plot 
shows two distinct minima associated with the three terminal hydrides 
known to be present, one a single well, the other a double well, as 
indicated by its extended shape, whose degeneracy must be lifted by 
appropriate use of the HLOC command to insert two hydrides into this 
double minimum [see  J. Chem. Soc., Dalton Trans., 1980, p 2510] (not 
the TERM search finds only a very low energy site in this pseudo-
single minimum).

JOB 3.	This job illustrated use of the HLOC instruction when 
investigating a triangular cluster compound [H3Ru3(CO)9CCH3], where 
the hydrides have been located from initial EDGE searches as bridging 
each edge of the cluster on the opposite side of the triangle from 
the face-capping m3-CCH3 group.   Three HLOC commands are used to 
allow for the non-bonded interactions between these hydrides enabling 
more accurate estimates of their positions to be made.   Their 
positions are refined in turn and the refined position output in the 
usual way.

JOB 4. This test job illustrates the ability of XHYDEX to find asymmetric
hydride bridges. The first instruction looks for a hydride along the
Pt-Ru3 edge at equal distances of 1.85A but with a large sigma of
0.4A.The output shows that the located hole is asymmetrically placed
along the Pt-Ru3 vector with a Pt-H  distance of ca 1.6A and an Ru-H
distance of ca 1.87A. The second instruction enters these more realistic
distances but with a much smaller sigma.The xray data for this compound
confirms the asymmetric nature of the Pt-H-Ru bridge

6.	RULES 
There are some rules which should be followed in order to use the 
program successfully:
(i)	Up to 150 atoms (including hydrides as input with HLOC) are 
permitted in the atom list.
(ii)	Up to 9 different atom types are permitted.
(iii)	Only one of EDGE, TERM or FACB is allowed per job segment 
i.e. before an END+ or END instruction.
(iv)	PLOT instructions must be preceded by a MATR instruction (and 
all atom instructions).
(v)	Only up to 10 unique minima may be located per job using TERM, 
EDGE or FACB commands.
(vi) 	HLOC instructions may not be used in the same job as TERM, 
EDGE or FACB commands.


7.	APPENDIX

7.1	Potential energy parameters, taken from N.V. Pavel, C. Quagliata 
and N. Scarcelli, Z. Krist. (1976), 144, 64.

Atom type	   a	  b	   c	d
     H	 6600	4.08	 49.2	0
     C	44800	2.04	125.0	6
     N	52100	2.04	132.0	6
     O	42000	2.04	132.7	6
 S or Cl	40500	3.85	265.2	0
    Me	49100	3.71	380.5	0
    Br	25650	3.56	366.7	0
     I	43400	3.54	527.8	0

I and Br serve as reasonable approximations for larger elements not 
listed e.g. the transition elements.

7.2	Metal-Hydride bond lengths
Accurate (neutron diffraction determined) bond length information on 
transition metal hydrides is relatively sparse but certain 
conclusions may be drawn about values suitable for use here.
(a)	Terminal hydride bond lengths are 0.1-0.2  shorter than those 
for edge bridging hydrides which are probably slightly shorter than 
those of face capping hydrides.
(b)	M-H distances follow fairly closely the trends in covalent 
radius shown by transition elements, i.e. bonds to 2nd and 3rd row 
elements of the same group are likely to be 0.1-0.2  longer than for 
the corresponding 1st row element, and a small drop in M-H bond 
length is likely  on traversing a row of the Periodic Table from left 
to right.

7.3	Some Neutron Determined Bond Lengths (). 
(see A.G. Orpen et al, J.Chem. Soc. Dalton Trans., 1989, S1, for 
another list).
Terminal:	Mn-H 1.60, Pt-H 1.60, Ir-H 1.60, Os-H 1.66, W-H 1.73, Re-H 
1.67, Ta-H 1.77
Edge Bridging:	Os-H 1.81-1.86, W-H 1.86-1.89, Cr-H 1.72, Mo-H 1.86, 
Re-H 1.88, Ru-H 1.79, Rh-H 1.78, Fe-H 1.67
Face Capping	Co-H 1.73, Ni-H 1.69, Os-H 1.93, Rh-H 1.8

